﻿/// <reference path="jquery-1.7.1.js" />

var userid;
var cid;
var sessionID;
var auth;
var itemid;
var templid;
var logindata;
var attachlist = [];
var uploadlist = [];
var savedata;


try {// Load root from config file.  Error if missing or unable to determine api address
    var root = getRoot();
} catch (e) {
    var i = window.location.pathname.indexOf('appsuite/api');
    if ( i > 0) {
        var path = window.location.pathname.substring(0, i) + 'appsuite/api/';
        root = window.location.protocol + "//" + window.location.host + path;
    } else alert('missing or corrupt config.js file');
}

var language = getURLParameter('lang');

$().ready(function () {// Once ready, load templates.  
    templid = getURLParameter("templid");
    // Add addditional templates here.  Specify template id, the template file, and the location
    log ('template id is ', templid);
    // Template for css.  Format cid-style.css
    if (templid !== null) {
        if (!isNaN(parseInt(templid))) {// Check cid is actually int, and if so, load templates styles
            getTemplate(templid, "header.html", "top-bar-placeholder");
            getTemplate(templid, "footer.html", "footer-placeholder");
            $('head').append('<link rel="stylesheet" type="text/css" href="./templates/' + templid + '-style.css">');
        }
    }
    $.get('./l10n/languages', function (languages) {
        var selectedLanguage = getURLParameter('lang');
        if (selectedLanguage === null) {
            selectedLanguage = "en_US";
        }
        $.each(languages, function (c, n) {
            if (c === selectedLanguage) {
                $('#languageSelect').append('<li class="active"><a href="#" language="' + c + '">' + n + '</a></li>');
                $('#languageSelectButton').html(n + ' <span class="caret"></span>');
            } else {
                $('#languageSelect').append('<li><a href="#" language="' + c + '">' + n + '</a></li>');
            }
        });
        
        var user = getURLParameter('user');
        if (user !== null) {
            $('#Username').val(user);
            $('#Password').focus();
        }
    }, 'json');

    // Language selection listener
    $("#languageSelect").click(loadLanguage);
});

function loadLanguage (ev) {
    var url = document.URL;
    if (url.indexOf("&lang") > 0) {
        url = url.substring (0, url.indexOf("&lang"));
    }
    url = url + "&lang=" + $(ev.target).attr("language");
    window.location.replace(url);
}

// Load the template.  Format should be cid-template .  Location in template subdirectory
function getTemplate (templid, template, locationID) {
    $.get('./templates/' + (templid === null ? "" : (templid + "-")) + template, function (data) {
        $('#' + locationID).replaceWith(data);
    })
    .fail(function () {// If not found with cid, try loading default
        $.get('./templates/' + template, function (data) {
            $('#' + locationID).replaceWith(data);
        });
    });
}


// Provides login to oxguard backend.  Authentication key is returned and stored
function login() {
    var username = $('#Username').val();
    var password = $('#Password').val();
    if(typeof String.prototype.trim === 'function') {// Trim not supported in IE
        password = $('#Password').val().trim();
    }
    $('#authorizing').show();
    logindata = {
            username : username,
            password : password
    }
    $.post(root + "oxguard/login?action=guest", JSON.stringify(logindata), function (data) {
        log("loging data: ", data);
        if (data === null) {
            alert('error');
            return;
        }
        if (data.auth === "Password Needed") {
            $('#login').hide();
            $('#NewPassword').show();
            userid = data.userid;
            cid = data.cid;
            sessionID = data.sessionID;
            auth = data.auth;
            return;
        }
        if (data.auth === "Bad Password" || data.auth === "No Key") {
            //#. Bad username or Password at login
            $('#ErrorBox').html(i18n.t("Bad username / Password"));
            $('#ErrorBox').show();
            $('#Username').focus();
            $('#Username').val('');
            $('#Password').val('');
            $('#authorizing').hide();
            return;
        }
        if (data.auth === "lockout") {
            $('#ErrorBox').html(i18n.t("Account locked out try later"));
            $('#ErrorBox').show();
            $('#Username').hide();
            $('#Password').hide();
            $('#LoginButton').hide();
            $('#authorizing').hide();
            return;
        }
        if (data.auth.length > 20) {
            okLogin(data);
            return;
        }
        if (data.auth === "PIN") {
            $('#authorizing').hide();
            $('#pin').show();
            $('#pinbox').focus();
            return;
        }

    })
    .fail(function (data) {
        $('#authorizing').hide();
        alert('fail');
    });
}

function okLogin(data) {
    userid = data.userid;
    cid = data.cid;
    sessionID = data.sessionID;
    auth = data.auth;
    var extrapass = getURLParameter("extrapass");
    if (extrapass !== null) extrapass = extrapass.trim();
    if (extrapass === 'true') {
        getExtraPass(data);
    } else {
        openreader(data, "");
    }
    logindata = null;
}

function loginPin() {
    logindata.pin = $('#pinbox').val();
    $.post(root + "oxguard/login?action=guest", JSON.stringify(logindata), function (data) {
        try {
            log("loging data: ", data);
            if (data.auth.length > 20) {
                okLogin(data);
                return;
            }
            if (data.auth === "Bad") {
                $('#PinErrorBox').html(i18n.t("Bad PIN")).show();
                $('#pinbox').val('').focus();
                return;
            }
            if (data.auth === "lockout") {
                $('#PinErrorBox').html(i18n.t("Account locked out try later")).show();
                $('#pinbox').val('').hide();
                $('#PinButton').hide();
                return;
            }
        } catch (e) {
            $('#PinErrorBox').html(i18n.t("Error checking PIN")).show();
            log(e);
        }
    })
    .fail(function () {
        $('#PinErrorBox').html(i18n.t("Error checking PIN")).show();
        return;
    });
}

function showChangepass() {
	view('NewPassword');
}

// Change the oxguard password
function changePass() {
    var pass1 = $('#new1').val();
    if (pass1 !== $('#new2').val()) {
        $('#new1').focus();
        $('#ChangeError').html(i18n.t("Passwords do not match"));
	$('#ChangeError').show();
        return;
    }
    var userdata = {
        newpass: pass1,
        oldpass: $('#old').val(),
        user_id: userid,
        sessionID: sessionID,
        cid: cid
    };
    $.post(root + 'oxguard/guest?action=changepass&session=' + sessionID, JSON.stringify(userdata), function (data) {
        if (typeof data === 'string') data = $.parseJSON(data);
        log('success ', data);
        if (data.auth.length > 20) {
            auth = data.auth;
            $('#new1').val('');
            $('#new2').val('');
            $('#old').val('');
            $('#ChangeError').removeClass('alert-danger').addClass('alert-success');
            $('#ChangeError').html(i18n.t("Password Changed"));
	    $('#ChangeError').show();
            window.setTimeout (function() {
		$('#ChangeError').html();
                $('#ChangeError').hide();
		view("Reader");
            }, 2000);

        }

    })
    .fail(function () {
        $('#ChangeError').html(i18n.t("Failed to change password"));
        $('#ChangeError').removeClass('alert-success').addClass('alert-danger').show();
    });
}

function showChangePassError (text) {
    $('#firstChangeError').html(text);
    $('#firstChangeError').show();
    if ($(window.top).height() < 800) // If small, scroll to bottom
        $('.passchange').animate ({ scrollTop: $('#firstChangeError').offset().top }, 1000);
}

//Change the oxguard password
function firstChangePass() {
    var pass1 = $('#change1').val();
    if (pass1.length < 8) {
        $('#change1').focus();
        showChangePassError(i18n.t("Password must be at least 8 characters long"));
        return;
    }
    if (pass1 !== $('#change2').val()) {
        $('#change1').focus();
        showChangePassError(i18n.t("Passwords do not match"));
        return;
    }
    var answer = $('#answer').val();
    if (answer.length < 3) {
        $('#answer').focus();
        showChangePassError(i18n.t("Please provide an answer for the security question"));
        return;
    }
    var password = $('#Password').val();
    if(typeof String.prototype.trim === 'function') { // Trim not supported in IE
        password = password.trim();
    }
    var userdata = {
        newpass: pass1,
        oldpass: password,
        question: $('#question').val(),
        answer: $('#answer').val(),
        user_id: userid,
        sessionID: sessionID,
        cid: cid
    };
    log("changepass data: ", userdata);
    $.post(root + 'oxguard/guest?action=changepass&session=' + sessionID, JSON.stringify(userdata), function (data) {
        if (typeof data === 'string') data = $.parseJSON(data);
        log('success ', data);
        if (data.auth.length > 20) {
            auth = data.auth;
            sessionID = data.sessionID;
            $('#new1').val('');
            $('#new2').val('');
            $('#firstChangeError').html(i18n.t("Password Changed"));
            $('#firstChangeError').removeClass('alert-danger').addClass('alert-success').show();
            window.setTimeout(function () {
                $('#firstChangeError').html();
                $('#firstChangeError').hide;
                $('#firstChangePassDiv').hide();
            },1000);
            $('#Reader').css("position", "inherit");
        }

    })
    .fail(function () {
        showChangePassError(i18n.t("Failed to change password"));
        $('#firstChangeError').removeClass('alert-success').addClass('alert-danger').show();
    });
}


// Extra password is required
function getExtraPass (data) {
	view("ExtraPassDiv");
	$('#ExtraPassButton').click(function () {
		var extra = $('#extrapass').val();
		openreader(data, extra);
	});
	$('#extrapass').focus()
	.keypress(function (e) {
	    if (e.which == 13) {
	        $('#ExtraPassButton').click();
	    }
	});
}

// Open the email for reading.  Populate with decoded data
function openreader(ldata, extra) {
    var lastMod = ldata.lastMod;
    view();
    $('#decoding').show();
    itemid = getURLParameter("email");
    var json = {
            cid : cid,
            item : itemid,
            extrapass : (extra === undefined) ? '' : extra
    }
    var url = root + 'oxguard/guest?action=getmail&session=' + sessionID + '&auth=' + encodeURIComponent(auth);
    $.post(url, JSON.stringify(json), function (data) {
        $('#Reader').show();
        log("reader data: ", data);
        if (data === null) {
            fail();
            return;
        }
        var toList = getTo(data),
            ccList = getCC(data);
        $('#sent').html('<td class="tdname">' + i18n.t("Sent") + '</td><td><span class=\"oxlabelcontent\">' + prepHTML(getSent(data)) + '</span></td>');
        if (toList.length > 2) {
            $('#tolist').html('<td class="tdname">' + i18n.t("To") + '</td><td><span class=\"oxlabelcontent\">' + prepHTML(toList) + '</span></td>').show();
        }
        log("cc: ", ccList);
        if (ccList.length > 2) {
            $('#cclist').html('<td class="tdname">' + i18n.t("Cc") +'</td><td><span class=\"oxlabelcontent\">' + prepHTML(ccList) + '</span></td>').show();
        }

        $('#fromlist').html('<td class="tdname">' + i18n.t("From") +'</td><td><span class=\"oxlabelcontent\">' + prepHTML(getFrom(data)) + '</span></td>');
        $('#subject').html(getSubject(data));
        $('#attdiv').remove();
        var readercont = $('#reader').contents().find('html');
        $('#reader').contents().find('html').html(getContent(data));
        $('#reader').contents().find('blockquote').css({'border-left': '1px solid #08C', 'padding': '7px 0 7px 19px', 'margin': '1em 0', 'opacity': '.5'});
        $('#header').after(getAttachments(data, itemid, auth));
        $('#decoding').hide();
        $('#reply').unbind().click(function() {
        	reply(data);
        });
        $('#replyall').unbind().click(function() {
        	replyall(data);
        });
        $('#reply-bottom').unbind().click(function() {
                reply(data);
        });
        $('#replyall-bottom').unbind().click(function() {
                replyall(data);
        });
        // Some squeeze for mobile
        if (window.screen.height < 800) {
            log('mobile detected');
            $('.padding').hide();
            $('.attachments').css('padding', '0');
        }
        log("last mod: ", lastMod);
        if (lastMod === 'null') {
            log('for changepass');
            window.setTimeout(function () {
                $('#Reader').css("position", "fixed");
                if((navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i))) {
                    $('.passchange').css('height', '100%').css('width', '100%').css('margin-top', '0%')
                    .bind('touchstart', function (e) {
                        console.log(e.target.type);
                        if (e.target.type !== 'password' && e.target.type !== 'text') {
                            document.activeElement.blur();
                        }
                    });
                }
                $('#firstChangePassDiv').show();
            },2000);
        }
        // Make all name columns same size.  Check for largest
        window.setTimeout(function() {
            var max = 0;
            $('.tdname').each(function(v, e) { 
                var w = $(e).width();
                if (w > max) max = w;
            });
            $('.tdname').width(max + 2);
        }, 100);

    })
    .fail(function (data) {
        log('fail', data);
        var resp = data.responseText;
        switch (resp.trim()) {
        case "badextra":
            fail("Bad Password");
            break;
        case "not found":
            view("NotFound");
            savedata = ldata;
            break;
        case "retracted":
            fail(i18n.t("This email is no longer available"));
            break;
        case "expired":
            fail(i18n.t("This email is no longer available"));
            break;
        default:
            fail();
            break;
        }
        
    });

}

function fail(alerttype)
{
    if (alerttype === undefined) {
        alert(i18n.t("An error occurred"));
    } else {
        alert(alerttype);
    }
    $('#authorizing').hide();
    $('#decoding').hide();
    view('login');
    log('fail');
}

// Get base url
function getURLParameter(name) {
    return decodeURIComponent((new RegExp('[?|&]' + name + '=' + '([^&;]+?)(&|#|;|$)').exec(location.search)||[,""])[1].replace(/\+/g, '%20'))||null
}

function cancelprop(e) {
    e.cancelBubble = true;
    e.returnValue = false;
    // non-ie
    e.preventDefault && e.preventDefault();
    e.stopPropagation && e.stopPropagation();
}

// Gets the language for TinyMCE from lang parameter in url
function getTinyLanguage () {
    var lang = getURLParameter('lang');
    var tinylang = "en";
    if (lang !== null) {
        $.get('./scripts/tinymce/langs/' + lang.toLowerCase() + '.js', function (data) {
            return(lang);
        })
        .fail (function () {
            lang = lang.toLowerCase();
            $.get('./scripts/tinymce/langs/' + lang.substring(0,2) + '.js', function (data) {
            log('setting tinylanguage to ' + lang.substring(0,2));
            return(lang.substring(0,2));
        });
        });
        return (tinylang);// otherwise return default
    }
}

// Add surrounding <> for emails
function surround(d) {
    return (' <' + d + '>');
}

function getList(recips) {
    var list = '';
    for (var i = 0; i < recips.length; i++) {
        if (i > 0) list += ', ';
        list += recips[i][0] + surround(recips[i][1]);
    }
    log("to: ", list);
    return (list);
}

// Get the to recipients
function getTo(data) {
    var recips = data.to;
    return (getList(recips));
}

function getReplyAllTo(replyto) {
    return (getList(replyto.replyAll))
}

function getCC(data) {
    var recips = data.cc;
    var list = '';
    if (recips === undefined) return (list);
    for (var i = 0; i < recips.length; i++) {
        if (i > 0) list += ', ';
        list += recips[i][0] + surround(recips[i][1]);
    }
    log("cc: ", list);
    return (list);
}

function getFrom(data) {
    return (data.from[0][0] + surround(data.from[0][1]));
}

function getSubject(data) {
    return (data.subject);
}

function prepHTML (data) {
    return $('<div/>').text(data).html();
}

function getSent(data) {
  //  var sent = new Date(Date.parse(data.sent));
  //  return (sent.toLocaleString());
    return(data.sent);
}

function getContent(data) {
    var attachments = data.attachments;
    var othertext = '';
    for (var i = 0; i < attachments.length; i++) {
        if (attachments[i].disp === 'inline') {
            if (attachments[i].content_type === 'text/html') {
                return (attachments[i].content);
            } else {
                othertext = attachments[i].content;
            }
        }
    }
    othertext = othertext.replace(/\n/g, '<br/>');
    return (othertext);
}

// Generate attachments.
function getAttachments(data, item, auth) {
    var attachmentdiv = $('<div id="attdiv"/>');
    var atttable = $('<table>');
    var row1 = $('<tr>');
    var attachments = data.attachments;
    var attcount = 0;
    var attd = $('<td>');
    for (var z = 0; z < attachments.length; z++) {
        var attach = attachments[z];
        if (attach.disp === 'attachment') {//If it is an attachment, we are going to display
            if (attcount === 0) {
                row1.append('<td class="io-ox-label" id="attlabel" style="vertical-align:top; padding-top:5px;">' + i18n.t("Attachment") + '</td>');
            }
            attcount++;
            // Create the link for that attachment
            var params = '&email=' + item +
            '&session=' + sessionID +
            "&userid=" + userid +
            "&cid=" + cid +
            (data.extrapass ? ('&encrextrapass=' + encodeURIComponent(data.extrapass)): "") +
            '&lang=' + language +
            '&attname=' + encodeURIComponent(attach.filename);
            var link = root + 'oxguard/guest?action=getattach' + params;
            var atlink = $('<a>', {
                "class": "attachment-link",
                text: attach.filename.replace('.grd2','').replace('.grd',''),
                "link": link,
                "href" : "#"
            }).css({
                'padding-right': '7px'
            }).click(function() {
                window.open($(this).attr("link") + "&auth=" + encodeURIComponent(getauth()));
            });
            attd.append($('<div class="attachment-link">').append(atlink));
        }
    }
    row1.append(attd);
    // Resize
    window.setTimeout(function () {
        try {
            var size = window.screen.width - $('#attlabel').width() - 50;
            $('.attachment-link').css('max-width', size);
        } catch (e) {
            console.log(e);
        }
    }, 100);
    return (attachmentdiv.append(atttable.append(row1)));
}

function getauth () {
    return(auth);
}

function getReplyData (data) {
    
    var replyTo = JSON.parse(JSON.stringify(data.from));
    var replyAll = JSON.parse(JSON.stringify(data.from));
    var thisEmail = $('#Username').val();
    var from = ["", thisEmail];
    // Loop through recipient list, make sure not this user, and if found, update name
    for (var i = 0; i < data.to.length; i++) {
        if (data.to[i][1] === thisEmail) {
            from = data.to[i];
        } else {
            replyAll.push(data.to[i]);
        }
    }
    for (var j = 0; j < data.cc.length; j++) {
        if (data.cc[j][1] === thisEmail) {
            from = data.cc[j];
        } else {
            replyAll.push(data.cc[j]);
        }
    }
    return {
        replyTo : replyTo,
        replyAll : replyAll,
        from : from
    }
}

function changeAttachments(attachments) {
    // Push to attachment list
    for (var i=0; i<attachments.files.length; i++) {
        attachlist.push(attachments.files[i]);
    }
    $(attachments).val('');  // Clear file list
    drawAttachments();
    
}




// Draw attachments for reply
function drawAttachments () {
    var list = '';
    $('.deleteAttach').unbind();
    for (var i=0; i< attachlist.length; i++) {
        if (i === 0) {
            list = createLink(attachlist[i]);
        } else {
            list = list + createLink(attachlist[i]);
        }
    }

    $('#attachmentList').html($('<ul>').append(list));
    $('.deleteAttach').click(function (e) {
        deleteAttachment($(e.target).parent().attr('data'));
        drawAttachments ();
    });
}

function createLink (file) {
    if (file === undefined) return('');
    var name = file.name;
    var div = $('<ul>');
    var span = $('<li>');
    var deletelink = $('<a href="#" id="delete-' + name + '" data="' + name + '" class="deleteAttach"></a>');
    var trash = $('<i class="fa fa-trash-o"></i>');
    deletelink.append(trash);
    div.append(span.append(deletelink).append(name));
    return (div.html());
}

function deleteAttachment (name) {
    for (var i =0; i < attachlist.length; i++) {
        if (attachlist[i] !== undefined) {
            if (attachlist[i].name.trim() === name.trim()) {
                delete attachlist[i];
                return;
            }
        }
    }
}

// Send the reply
function sendreply(data, all) {
    var replydata = getReplyData (data);
    log('replydata', replydata);
	var to = replydata.replyTo;
	if (all) {
		to = replydata.replyAll;
	}
	log('reply to ', to);
	var from = replydata.from;
	//#. For the prefix of the subject reply I.E. Re: The message you sent
	var subject = i18n.t("re") + ': ' + data.subject;
	var format = $('[name="format"]:checked').val();
	var content;
	if (format === 'html') {
	    content = tinyMCE.activeEditor.getContent();
	}
	else {
	    content = $('.plaintexteditor').val();
	} 

	var mail = createJson (to, from, subject, content, data, format);
	log (mail);
	var formData = new FormData();
    formData.append('json_0', JSON.stringify(mail));
    log('attachments', attachlist);
    for (var l = 0; l < attachlist.length; l++) {
        if (attachlist[l] !== undefined)
            formData.append('file' + l, attachlist[l]);
    }
    var xhr = new XMLHttpRequest();
    var url = root + 'oxguard/mail?action=emailform' +
    '&session=' + sessionID + '&userid=' + userid + '&cid=' + cid + "&guest=true&sr=" + itemid + "&auth=" + encodeURIComponent(auth) +
    (!isNaN(parseInt(templid)) ? ("&templid=" + templid) : "");
    $.ajax({
        url: url,
        type: "POST",
        data: formData,
        processData: false,  // tell jQuery not to process the data
        contentType: false,   // tell jQuery not to set contentType
        xhr: function() {
            var myXhr = $.ajaxSettings.xhr();
            if (myXhr.upload) {
                myXhr.upload.addEventListener('progress',function(ev) {
                    if (ev.lengthComputable) {
                        var percentComplete = Math.floor(ev.loaded * 100 / ev.total);
                        $('#sendingProgress').attr('aria-valuenow', percentComplete)
                        .css('width', percentComplete + '%');
                        log('Uploaded '+percentComplete+'%');
                        // update UI to reflect percentUploaded
                    }
               }, false);
            }
            return myXhr;
        },
        success: function(data){
            view("results");
            $('#sendresult').html(i18n.t("Encrypted email reply has been sent successfully"));
            window.setTimeout(function () {
                view("Reader");
            },2000);
            $('#sending').hide();
        },
        error: function (XMLHttpRequest, textStatus, errorThrown) {
            log(errorThrown);
            view("results");
            if (XMLHttpRequest.responseText.trim() === 'not authorized') {
                $('#sendresult').html(i18n.t("The authorization to send a reply was not valid  Did you have another reader open?  Please reload and log in again"));
            } else {
                $('#sendresult').html(i18n.t("An error occurred during sending the encrypted email reply"));
            }
            
            $('#sending').hide();
        }
      });
    $('#sending').show();

}

function reply(data) {
    initReply(data);
	$('#rto').html('<span>' + prepHTML(getFrom(data)) + '</span>').show();
}

function replyall(data) {
    initReply (data);
    var replydata = getReplyData (data);
    $('#rto').html('<span>' + prepHTML(getReplyAllTo(replydata)) + '</span>').show();
}

function initReply (data) {
    $('[name="format"][value="html"]').prop("checked", true);
    $('.plaintexteditor').val('');
    attachlist = [];
    drawAttachments();
    $('#rsubject').html(i18n.t("re") + ': ' + data.subject);
    var bm = tinyMCE.activeEditor.selection.getBookmark();
    tinyMCE.activeEditor.setContent(formatReply(data));
    tinyMCE.activeEditor.selection.moveToBookmark(bm);
    tinyMCE.activeEditor.focus();
    view('replydiv');
    $('#SendReply').unbind().click(function() {
        sendreply(data, true);
    });
    $('.plaintexteditor').hide();
    $('.mce-tinymce').show();
}

function formatReply (data) {
    var orig = '<span>' + i18n.t("Original message from") + ' ' + getFrom(data) + ' ' + i18n.t("Sent") + ' ' + getSent(data) + '</span><div style="float:none; height:10px;"></div>';
    var message = '<br/><br/><blockquote type="cite">' + orig + getContent(data) + "</blockquote>";
    return (message);
}

function changeformat(radio) {
    if ($(radio).val() === 'html') {
        var text = $('.plaintexteditor').val();
        var bm = tinyMCE.activeEditor.selection.getBookmark();
        tinyMCE.activeEditor.setContent(convertPlain(text));
        tinyMCE.activeEditor.selection.moveToBookmark(bm);
        tinyMCE.activeEditor.focus();
        $('.plaintexteditor').hide();
        $('.mce-tinymce').show();
    } else {
        var content = tinyMCE.activeEditor.getContent();
        var editor = $('.plaintexteditor');
        editor.val(unescapeHtml(convertHTML(content))).show().focus().scrollTop(0);
        editor[0].setSelectionRange(1,1);
        editor[0].focus();
        $('.mce-tinymce').hide();
    }
}

function unescapeHtml(text) {
    return text.replace(/&amp;/g, '&')
        .replace(/&lt;/g, '<')
        .replace(/&gt;/g, '>')
        .replace(/&quot;/g, '"')
        .replace(/&nbsp;/g, ' ')
        .replace(/&#039;/g, "'");
}

function nochange() {
    $('#firstChangePassDiv').hide();
    $('#Reader').css("position", "inherit");
}

// Create the json required from the ox backend
function createJson(to, from, subject, content, origMail, format) {
	var attachments = {
			content : content,
			content_type : (format === 'html' ? "text/html" : "text/plain")
	};
	var headers = {"X-OxGuard-Expiration" : 0, "X-OxGuard-ExtraPass" : ""};
	   if (origMail.headers['Message-ID'] !== undefined) {
	        headers['In-Reply-To'] = origMail.headers['Message-ID'];
	        if (origMail.headers.References !== undefined) {
	            headers['References']= (origMail.headers['References'] + origMail.headers['Message-ID']);
	        } else {
	            headers['References'] = origMail.headers['Message-ID'];
	        }
	    }
	var data = {
			from : [from],
			to : to,
			cc : [],
			bcc : [],
			headers : headers,
			reply_to : from,
			subject : subject,
			priority : 3,
			vcard : 0,
			attachments : [attachments],
			nested_msgs : [],
			sendtype: 0,
			contact_ids: [],
			infostore_ids: []
	};

	var json = {
			data : data,
			files : [],
			format : "html",
			mode : "compose",
			signature: ""
	};
	log('returnJson', json);
	return (json);

}

function forgotPass() {
    var email = $('#EmailAddr').val();
    if (email.indexOf("@") > 1) {
        $('#wait').show();
        var url = root + 'oxguard/guest?action=getquestion&email=' + email;
        $.get(url, function (data) {
            log ('Reset get question ', data);
            if (data.trim() === "nf") {
                $('#EmailAddr').focus();
                $('#ForgotError').html(i18n.t("Please provide valid email address"));
                $('#ForgotError').show();
                $('#wait').hide();
                return;
            }
            if ((data.indexOf("default") > -1) || (data === "")) {
                $('#AskForgotQuestion').text(i18n.t("Favorite Movie"));
            } else {
                $('#AskForgotQuestion').text(data);
            }
            $('#wait').hide();
            if ((data.trim() === "null") || (data.trim() === "PIN")) {// If no recovery answer yet set up, reset
                forgotPass2()
                $('#wait').show();
            } else {
                view ('ForgotPage2');
            }
        })
        .fail (function () {
            $('#ForgotError').html(i18n.t("Failed to connect to server"));
	    $('#ForgotError').show();
        });
        
    } else {
        $('#EmailAddr').focus();
        $('#ForgotError').html(i18n.t("Please provide valid email address"));
        $('#ForgotError').show();
    }
    
}

function forgotPass2() {
    var email = $('#EmailAddr').val();
    var answer = $('#forgotAnswer').val();
    $('#ForgotError2').hide();
    $('#wait2').show();
    var url = root + 'oxguard/guest?action=resetpassword&email=' + email + '&answer=' + answer + '&language=' + language;
    $.get(url, function (data) {
        log("forgot2", data);
        $('#wait2').hide();
        if (data.indexOf('OK') > -1) {
            alert (i18n.t("Password Emailed"));
            view ('login');
        }
        if (data.indexOf('FailNotify') > -1) {
            alert (i18n.t("Failed to change password"));
            view ('login');
        }
        if (data.trim() === 'No Match') {
            $('#ForgotError2').html(i18n.t("Incorrect Answer"));
            $('#ForgotError2').show();
        }
        if (data.trim() === 'lockout') {
            $('#ForgotError2').html(i18n.t("Temporary account lockout"));
            $('#ForgotError2').show();
        }
    })
    .fail (function (data) {
        $('#wait2').hide();
        $('#wait').hide();
        log("Forgot2 fail ", data);
        $('#ForgotError2').html(i18n.t("Failed to change password"));
        $('#ForgotError2').show();
    });
}

function view (element) {
    $('.view').hide();
    if (element !== undefined)
    	$('#' + element).show();

}

// Convert HTML email to plaintext
function convert (html, start) {
    try {
        if (start === undefined)
            start = 0;
        var i = html.indexOf('<blockquote', start);
        if (i > -1) {
            i = html.indexOf('>', i) + 1;
            html = convert(html, i);
        }
        var j = html.indexOf('</blockquote');
        var substring = html.substring(start);
        if (j > -1) {
            substring = html.substring(start, j);
        } 
        var repl = '\n';
        if (i > -1) repl = '\n> ';
        var newstring = substring.replace(/\n/g, repl).replace(/<br[ \/]*>/gi, repl)
                .replace(/<p[\/]*>/gi, repl).replace(/<blockquote[^>]*>/,repl).replace(/<(?:.|\s)*?>/g, '') + repl;
        html = html.replace(substring, newstring);
        return (html);
    } catch (e) {
        console.log(e);
        return (html);
    }
}

function convertHTML(html) {
    return (' \n' + convert(html, 0).replace(/<blockquote[^>]*>/,'\n ').replace(/<(?:.|\s)*?>/g, ''));
}

function convertPlain (plain) {
    if (plain.indexOf(' \n') === 0) {  // If starts withour padding at top, remove
        return (plain.substring(3).replace(/\n/g, '<br>').replace(/>\n/, '<br>'));
    }
    return (plain.replace(/\n/g, '<br>').replace(/>\n/, '<br>'));
}

////////  Section for re-uploading email attachments if the cache has expired

function changeUploadList(uploads) {
    for (var i=0; i<uploads.files.length; i++) {
        uploadlist.push(uploads.files[i]);
    }
    $(uploads).val('');  // Clear file list
    drawUploads();
}

//Draw upload list
function drawUploads () {
    var list = '';
    $('.deleteAttach').unbind();
    for (var i=0; i< uploadlist.length; i++) {
        if (i === 0) {
            list = createLink(uploadlist[i]);
        } else {
            list = list + createLink(uploadlist[i]);
        }
    }

    $('#uploadList').html($('<ul>').append(list));
    $('.deleteAttach').click(function (e) {
        deleteUpload($(e.target).parent().attr('data'));
        drawUploads ();
    });
}

function deleteUpload (name) {
    for (var i =0; i < uploadlist.length; i++) {
        if (uploadlist[i] !== undefined) {
            if (uploadlist[i].name.trim() === name.trim()) {
                delete uploadlist[i];
                return;
            }
        }
    }
}

function uploadEmail() {
    if (uploadlist.length > 0) {
        var formData = new FormData();
        log('To upload', uploadlist);
        for (var l = 0; l < uploadlist.length; l++) {
            if (uploadlist[l] !== undefined)
                formData.append('file' + l, uploadlist[l]);
        }
    } else {
        alert (i18n.t('No files selected'));
        return;
    }
    // Reset upload bar
    $('#uploadProgress').attr('aria-valuenow', 0)
    .css('width', '0%');
    $('#uploading').show();
    var url = root + 'oxguard/guest?action=upload' +
    '&session=' + sessionID + '&userid=' + userid + '&cid=' + cid + "&auth=" + encodeURIComponent(auth);
    $.ajax({
        url: url,
        type: "POST",
        data: formData,
        processData: false,  // tell jQuery not to process the data
        contentType: false,   // tell jQuery not to set contentType
        xhr: function() {
            var myXhr = $.ajaxSettings.xhr();
            if (myXhr.upload) {
                myXhr.upload.addEventListener('progress',function(ev) {
                    if (ev.lengthComputable) {
                        var percentComplete = Math.floor(ev.loaded * 100 / ev.total);
                        $('#uploadProgress').attr('aria-valuenow', percentComplete)
                        .css('width', percentComplete + '%');
                        log('Uploaded '+percentComplete+'%');
                        // update UI to reflect percentUploaded
                    }
               }, false);
            }
            return myXhr;
        },
        success: function(data){
            $('#uploading').hide();
            okLogin(savedata);
        },
        error: function (XMLHttpRequest, textStatus, errorThrown) {
            log(XMLHttpRequest);
            $('#uploading').hide();
            switch (XMLHttpRequest.responseText.trim()) {
            case "Not valid Guard files":
                alert (i18n.t('Not a valid encrypted file  Look for file with suffix of grd'));
                return;
            case "not decodable":
                alert (i18n.t('Cannot decode that file  Correct password?  Correct Guard system?'));
                return;
            case "Storage failure":
                alert (i18n.t('The server was unable to store that file'));
                return;
            default:
                alert(i18n.t('Problem uploading the file'));
                return;
            }
        }
    });
}


function log (where, data) {
    if (!debug) return;
    if (typeof console === "undefined" || typeof console.log === "undefined") return;// Close if IE dev tools not open
    console.log(where);
    console.log(data);
}

var debug = (getURLParameter("debug") === "1");



